@@ -11,7 +11,7 @@
 #' 
 info.rank.bcea <- function(he,
                            inp,
-                           wtp = he$k[min(which(he$k >= he$ICER))],
+                           wtp = NULL,
                            howManyPars = NA,
                            graph = c("base", "ggplot2", "plotly"),
                            rel = TRUE,
@@ -68,7 +68,7 @@ info.rank.bcea <- function(he,
 #' not specified then the break-even point for the current model will be used.
 #' @param howManyPars Optional maximum number of parameters to be included in the bar plot. 
 #' Includes all parameters by default. 
-#' @param graph A string used to select the graphical enging to use for plotting.
+#' @param graph A string used to select the graphical engine to use for plotting.
 #' Should (partial-)match one of the two options "base" or "plotly". Default value is "base"
 #' @param rel Logical argument that specifies whether the ratio of
 #' EVPPI to EVPI (\code{rel = TRUE}, default) or the absolute value of the EVPPI
@@ -95,24 +95,28 @@ info.rank.bcea <- function(he,
 #' @author Anna Heath, Gianluca Baio, Andrea Berardi
 #' @seealso \code{\link{bcea}},
 #'          \code{\link{evppi}}
+#' @importFrom Rdpack reprompt
 #' 
 #' @references
-#' Baio, G., Dawid, A. P. (2011). Probabilistic Sensitivity
-#' Analysis in Health Economics. Statistical Methods in Medical Research
-#' doi:10.1177/0962280211419832.
+#' \insertRef{Baio2011}{BCEA}
+#' 
+#' \insertRef{Baio2013}{BCEA}
 #' 
-#' Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London.
 #' @keywords dplot models
 #' 
 #' @export
 #' 
 #' @examples
+#' \dontrun{
+#' # Load the post-processed results of the MCMC simulation model
+#' # original JAGS output is can be downloaded from here
+#' # https://gianluca.statistica.it/book/bcea/code/vaccine.RData
+#' 
 #' data("Vaccine")
-#' m <- bcea(e,c)
-#' inp <- createInputs(vaccine)
+#' m <- bcea(eff, cost)
+#' inp <- createInputs(vaccine_mat)
 #' info.rank(m, inp)
 #' 
-#' \dontrun{
 #' info.rank(m, inp, graph = "base")
 #' info.rank(m, inp, graph = "plotly")
 #' info.rank(m, inp, graph = "ggplot2")
